pecos.simulators.paulifaultprop.gates\_init
===========================================

.. automodule:: pecos.simulators.paulifaultprop.gates_init







   .. rubric:: Functions

   .. autosummary::

      init
